##  Overview
The AI agent discovery inbox displays AI agents and MCP servers discovered from all configured integrations for AI agent discovery. You can review discovered items and link them to relevant fact sheets. For AI agents, you’ll also receive suggestions for linking agents to business capabilities in your workspace. If any items aren’t relevant, you can reject them.
**Note**
Before using the inbox, activate the AI agent extension to the meta model. You’ll be prompted to do this when enabling related integrations. To learn more, see [AI Agent Extension to the Meta Model](https://help.sap.com/docs/leanix/ea/ai-agent-extension-to-meta-model?locale=en-US&state=PRODUCTION&version=CLOUD "Activate an optional meta model extension to model and govern your organization’s AI agents and MCP servers.").
![](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/loio20a37ad3308e49298ef02aab596859bd_LowRes.png)
AI Agent Discovery Inbox with Discovered Agents and MCP Servers
